from setuptools import setup

setup(name='mlintro_distrib',
      version='0.1',
      description='Gaussian distributions',
      packages=['mlintro_distrib'],
      author_email='isaac.gutierrez@msn.com',
      zip_safe=False)
